@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2009 T.W. Yee, University of Auckland. All rights reserved.
+# Copyright (C) 1998-2010 T.W. Yee, University of Auckland. All rights reserved.
 
 
 
@@ -29,10 +29,10 @@ vgam <- function(formula,
 
     ocall <- match.call()
 
-    if(smart)
+    if (smart)
         setup.smart("write")
 
-    if(missing(data))
+    if (missing(data))
         data <- environment(formula)
 
     mtsave <- terms(formula, "s", data = data)
@@ -55,21 +55,21 @@ vgam <- function(formula,
     attr(x, "assign") = attrassigndefault(x, mt)
 
     offset <- model.offset(mf)
-    if(is.null(offset))
+    if (is.null(offset))
         offset <- 0 # yyy ???
 
 
 
 
     mf2 = mf
-    if(!missing(subset)) {
+    if (!missing(subset)) {
         mf2$subset <- NULL 
         mf2 <- eval(mf2, parent.frame())   # mf2 is the full data frame. 
         spars2 =  lapply(mf2, attr, "spar") 
         dfs2 =  lapply(mf2, attr, "df") 
         sx2 =  lapply(mf2, attr, "s.xargument") 
         for(i in 1:length(mf)) {
-            if(length(sx2[[i]])) {
+            if (length(sx2[[i]])) {
                 attr(mf[[i]], "spar") = spars2[[i]]
                 attr(mf[[i]], "dfs2") = dfs2[[i]]
                 attr(mf[[i]], "s.xargument") = sx2[[i]]
@@ -81,9 +81,9 @@ vgam <- function(formula,
 
 
     w <- model.weights(mf)
-    if(!length(w))
+    if (!length(w))
         w <- rep(1, nrow(mf))
-    else if(ncol(as.matrix(w))==1 && any(w < 0))
+    else if (ncol(as.matrix(w))==1 && any(w < 0))
         stop("negative weights not allowed")
 
 
@@ -93,7 +93,7 @@ vgam <- function(formula,
         family <- get(family)
     if (is.function(family))
         family <- family()
-    if(!inherits(family, "vglmff")) {
+    if (!inherits(family, "vglmff")) {
         stop("'family=", family, "' is not a VGAM family function")
     }
 
@@ -101,18 +101,18 @@ vgam <- function(formula,
 
     n <- dim(x)[1]
 
-    if(FALSE && is.R()) {
+    if (FALSE && is.R()) {
         family@inverse <- eval(family@inverse)
         family@link <- eval(family@link)
 
         for(i in names(.min.criterion.VGAM)) 
-            if(length(family[[i]])) family[[i]] <- eval(family[[i]])
+            if (length(family[[i]])) family[[i]] <- eval(family[[i]])
     }
 
-    if(length(slot(family, "first")))
+    if (length(slot(family, "first")))
         eval(slot(family, "first"))
 
-    if(method != "vgam.fit")
+    if (method != "vgam.fit")
         stop("method must be \"model.frame\" or \"vgam.fit\"")
 
     # --------------------------------------------------------------
@@ -123,10 +123,10 @@ vgam <- function(formula,
 
 
     nonparametric <- length(smoothers$s) > 0
-    if(nonparametric) {
+    if (nonparametric) {
 
         ff <- apply(aa$factors[smoothers[["s"]],,drop=FALSE], 2, any)
-        smoothers[["s"]] <- if(any(ff)) seq(along=ff)[aa$order==1 & ff] else
+        smoothers[["s"]] <- if (any(ff)) seq(along=ff)[aa$order==1 & ff] else
             NULL
 
         smooth.labels <- aa$term.labels[unlist(smoothers)]
@@ -145,13 +145,13 @@ vgam <- function(formula,
         function.name=function.name, ...)
 
 
-    if(is.Numeric(fit$nl.df) && any(fit$nl.df < 0)) {
+    if (is.Numeric(fit$nl.df) && any(fit$nl.df < 0)) {
         fit$nl.df[fit$nl.df < 0] = 0
     }
 
     # --------------------------------------------------------------
 
-    if(!is.null(fit[["smooth.frame"]])) {
+    if (!is.null(fit[["smooth.frame"]])) {
         fit <- fit[-1]       # Strip off smooth.frame
     } else {
     }
@@ -159,21 +159,21 @@ vgam <- function(formula,
     fit$smooth <- NULL          # Not needed
 
     fit$call <- ocall 
-    if(model)
+    if (model)
         fit$model <- mf 
-    if(!x.arg)
+    if (!x.arg)
         fit$x <- NULL
-    if(!y.arg)
+    if (!y.arg)
         fit$y <- NULL
 
-    if(nonparametric)
+    if (nonparametric)
         fit$misc$smooth.labels <- smooth.labels
 
 
     fit$misc$dataname <- dataname
 
 
-    if(smart)
+    if (smart)
         fit$smart.prediction <- get.smart.prediction()
 
 
@@ -188,7 +188,7 @@ vgam <- function(formula,
       "dispersion"   = 1,
       "family"       = fit$family,
       "misc"         = fit$misc,
-      "model"        = if(model) mf else data.frame(),
+      "model"        = if (model) mf else data.frame(),
       "R"            = fit$R,
       "rank"         = fit$rank,
       "residuals"    = as.matrix(fit$residuals),
@@ -196,34 +196,34 @@ vgam <- function(formula,
       "smart.prediction" = as.list(fit$smart.prediction),
       "terms"        = list(terms=fit$terms))
 
-    if(!smart) answer@smart.prediction <- list(smart.arg=FALSE)
+    if (!smart) answer@smart.prediction <- list(smart.arg=FALSE)
 
-    if(qr.arg) {
+    if (qr.arg) {
         class(fit$qr) = "list"
         slot(answer, "qr") = fit$qr
     }
-    if(length(attr(x, "contrasts")))
+    if (length(attr(x, "contrasts")))
         slot(answer, "contrasts") = attr(x, "contrasts")
-    if(length(fit$fitted.values))
+    if (length(fit$fitted.values))
         slot(answer, "fitted.values") = as.matrix(fit$fitted.values)
-    slot(answer, "na.action") = if(length(aaa <- attr(mf, "na.action")))
+    slot(answer, "na.action") = if (length(aaa <- attr(mf, "na.action")))
         list(aaa) else list()
-    if(length(offset))
+    if (length(offset))
         slot(answer, "offset") = as.matrix(offset)
-    if(length(fit$weights))
+    if (length(fit$weights))
         slot(answer, "weights") = as.matrix(fit$weights)
-    if(x.arg)
+    if (x.arg)
         slot(answer, "x") = x # The 'small' design matrix
-    if(length(xlev))
+    if (length(xlev))
         slot(answer, "xlevels") = xlev
-    if(y.arg)
+    if (y.arg)
         slot(answer, "y") = as.matrix(fit$y)
     answer@misc$formula = formula
 
 
     slot(answer, "control") = fit$control
 
-    if(length(fit$extra)) {
+    if (length(fit$extra)) {
         slot(answer, "extra") = fit$extra
     }
     slot(answer, "iter") = fit$iter
@@ -233,18 +233,18 @@ vgam <- function(formula,
     dimnames(fit$predictors) = list(dimnames(fit$predictors)[[1]],
                                     fit$misc$predictors.names)
     slot(answer, "predictors") = fit$predictors
-    if(length(fit$prior.weights))
+    if (length(fit$prior.weights))
         slot(answer, "prior.weights") = fit$prior.weights
 
 
-    if(nonparametric) {
+    if (nonparametric) {
         slot(answer, "Bspline") = fit$Bspline
         slot(answer, "nl.chisq") = fit$nl.chisq
-        if(is.Numeric(fit$nl.df))
+        if (is.Numeric(fit$nl.df))
             slot(answer, "nl.df") = fit$nl.df
         slot(answer, "spar") = fit$spar
         slot(answer, "s.xargument") = fit$s.xargument
-        if(length(fit$var)) {
+        if (length(fit$var)) {
             slot(answer, "var") = fit$var
         }
 
@@ -254,7 +254,7 @@ vgam <- function(formula,
 
 
     }
-    if(length(fit$effects))
+    if (length(fit$effects))
         slot(answer, "effects") = fit$effects
 
 
@@ -265,8 +265,7 @@ attr(vgam, "smart") <- TRUE
 
 
 
-care.exp <- function(x, thresh = -log(.Machine$double.eps))
-{
+care.exp <- function(x, thresh = -log(.Machine$double.eps)) {
     x[x > thresh] <- thresh
     x[x < (-thresh)] <-  -thresh
     exp(x)
